using System.ComponentModel;
using System.Configuration;
using System.Data.SqlClient;
using System.Data.OleDb;
using System.Data.Odbc;
using System.Data;

namespace AdhiC.db
{
	/// <summary>
	/// Summary description for AdhiDBCommand.
	/// </summary>
	public abstract class AdhiDBCommand
	{
		// the command to be execute
		protected Component command; 
		
	
		//get the instance of a command based on the type defined in
		//app.config file
		public static AdhiDBCommand getInstance(string commandStr,AdhiDBConnection conn)
		{
			return getInstance(
                ConfigurationManager.AppSettings[AdhiConstants.DB_TYPE], 
                commandStr, conn);
		}
		//get the instance of a command based on the dbtype 
		public static AdhiDBCommand getInstance(string dbType,string commandStr,AdhiDBConnection conn)
		{
			AdhiDBCommand cmd = null;
			if(AdhiConstants.MS_ACCESS.Equals(dbType))
			{
				cmd = new AdhiOleDBCommand(commandStr,(OleDbConnection)conn.Connection);
			}
			else if(AdhiConstants.SQL_SERVER.Equals(dbType))
			{
				cmd = new AdhiSQLCommand(commandStr,(SqlConnection)conn.Connection);
			}
			else if(AdhiConstants.ODBC_DRIVER.Equals(dbType))
			{
				cmd = new AdhiOdbcCommand(commandStr,(OdbcConnection)conn.Connection);
			}
			return cmd;
		}
	    public abstract int ExecuteNonQuery();
        public abstract int ExecuteScalar() ;

        public abstract void SetCommandText(string cmdStr);
		public abstract void SetCommandType(CommandType cmdType);
		public abstract void SetParameters( string[] variables,object[] values);
		public abstract DataSet Find();
	}
}
